Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorddunne2010-05-28 22:44:40 +0000
committerddunne2010-05-28 22:44:40 +0000
commiteb2212d1c201c0c9cf74d8607528d6b72da311c7 (patch)
tree5ca4242b02472c346e832aabccf99182bd6f048b /plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging
parente5403b6abc4aef4525ac7534505f2ada24766d59 (diff)
downloadorg.eclipse.osee-eb2212d1c201c0c9cf74d8607528d6b72da311c7.tar.gz
org.eclipse.osee-eb2212d1c201c0c9cf74d8607528d6b72da311c7.tar.xz
org.eclipse.osee-eb2212d1c201c0c9cf74d8607528d6b72da311c7.zip
events - purge transaction
Diffstat (limited to 'plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging')
-rw-r--r--plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/ObjectFactory.java111
-rw-r--r--plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemotePersistEvent1.java187
-rw-r--r--plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionChange1.java (renamed from plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionDeletedEvent1.java)105
-rw-r--r--plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionEvent1.java94
4 files changed, 381 insertions, 116 deletions
diff --git a/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/ObjectFactory.java b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/ObjectFactory.java
new file mode 100644
index 00000000000..c3b83ce606f
--- /dev/null
+++ b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/ObjectFactory.java
@@ -0,0 +1,111 @@
+//
+// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vJAXB 2.1.3 in JDK 1.6
+// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
+// Any modifications to this file will be lost upon recompilation of the source schema.
+// Generated on: 2010.05.28 at 02:08:30 PM MST
+//
+
+
+package org.eclipse.osee.framework.messaging.event.res.msgs;
+
+import javax.xml.bind.annotation.XmlRegistry;
+
+
+/**
+ * This object contains factory methods for each
+ * Java content interface and Java element interface
+ * generated in the org.eclipse.osee.framework.messaging.event.res.msgs package.
+ * <p>An ObjectFactory allows you to programatically
+ * construct new instances of the Java representation
+ * for XML content. The Java representation of XML
+ * content can consist of schema derived interfaces
+ * and classes representing the binding of schema
+ * type definitions, element declarations and model
+ * groups. Factory methods for each of these are
+ * provided in this class.
+ *
+ */
+@XmlRegistry
+public class ObjectFactory {
+
+
+ /**
+ * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.eclipse.osee.framework.messaging.event.res.msgs
+ *
+ */
+ public ObjectFactory() {
+ }
+
+ /**
+ * Create an instance of {@link RemoteBranchEvent1 }
+ *
+ */
+ public RemoteBranchEvent1 createRemoteBranchEvent1() {
+ return new RemoteBranchEvent1();
+ }
+
+ /**
+ * Create an instance of {@link RemoteBasicGuidArtifact1 }
+ *
+ */
+ public RemoteBasicGuidArtifact1 createRemoteBasicGuidArtifact1() {
+ return new RemoteBasicGuidArtifact1();
+ }
+
+ /**
+ * Create an instance of {@link RemoteNetworkSender1 }
+ *
+ */
+ public RemoteNetworkSender1 createRemoteNetworkSender1() {
+ return new RemoteNetworkSender1();
+ }
+
+ /**
+ * Create an instance of {@link RemoteBroadcastEvent1 }
+ *
+ */
+ public RemoteBroadcastEvent1 createRemoteBroadcastEvent1() {
+ return new RemoteBroadcastEvent1();
+ }
+
+ /**
+ * Create an instance of {@link RemoteTransactionEvent1 }
+ *
+ */
+ public RemoteTransactionEvent1 createRemoteTransactionEvent1() {
+ return new RemoteTransactionEvent1();
+ }
+
+ /**
+ * Create an instance of {@link RemoteAttributeChange1 }
+ *
+ */
+ public RemoteAttributeChange1 createRemoteAttributeChange1() {
+ return new RemoteAttributeChange1();
+ }
+
+ /**
+ * Create an instance of {@link RemoteTransactionChange1 }
+ *
+ */
+ public RemoteTransactionChange1 createRemoteTransactionChange1() {
+ return new RemoteTransactionChange1();
+ }
+
+ /**
+ * Create an instance of {@link RemoteBasicGuidRelation1 }
+ *
+ */
+ public RemoteBasicGuidRelation1 createRemoteBasicGuidRelation1() {
+ return new RemoteBasicGuidRelation1();
+ }
+
+ /**
+ * Create an instance of {@link RemotePersistEvent1 }
+ *
+ */
+ public RemotePersistEvent1 createRemotePersistEvent1() {
+ return new RemotePersistEvent1();
+ }
+
+}
diff --git a/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemotePersistEvent1.java b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemotePersistEvent1.java
new file mode 100644
index 00000000000..49a69340cb4
--- /dev/null
+++ b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemotePersistEvent1.java
@@ -0,0 +1,187 @@
+//
+// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vJAXB 2.1.3 in JDK 1.6
+// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
+// Any modifications to this file will be lost upon recompilation of the source schema.
+// Generated on: 2010.05.28 at 02:08:30 PM MST
+//
+
+
+package org.eclipse.osee.framework.messaging.event.res.msgs;
+
+import java.util.ArrayList;
+import java.util.List;
+import javax.xml.bind.annotation.XmlAccessType;
+import javax.xml.bind.annotation.XmlAccessorType;
+import javax.xml.bind.annotation.XmlElement;
+import javax.xml.bind.annotation.XmlType;
+import org.eclipse.osee.framework.messaging.event.res.RemoteEvent;
+
+
+/**
+ * <p>Java class for RemotePersistEvent1 complex type.
+ *
+ * <p>The following schema fragment specifies the expected content contained within this class.
+ *
+ * <pre>
+ * &lt;complexType name="RemotePersistEvent1">
+ * &lt;complexContent>
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+ * &lt;sequence>
+ * &lt;element name="branchGuid" type="{http://www.w3.org/2001/XMLSchema}string"/>
+ * &lt;element name="transactionId" type="{http://www.w3.org/2001/XMLSchema}int"/>
+ * &lt;element name="artifacts" type="{}RemoteBasicGuidArtifact1" maxOccurs="unbounded"/>
+ * &lt;element name="relations" type="{}RemoteBasicGuidRelation1" maxOccurs="unbounded"/>
+ * &lt;element name="networkSender" type="{}RemoteNetworkSender1"/>
+ * &lt;/sequence>
+ * &lt;/restriction>
+ * &lt;/complexContent>
+ * &lt;/complexType>
+ * </pre>
+ *
+ *
+ */
+@XmlAccessorType(XmlAccessType.FIELD)
+@XmlType(name = "RemotePersistEvent1", propOrder = {
+ "branchGuid",
+ "transactionId",
+ "artifacts",
+ "relations",
+ "networkSender"
+})
+public class RemotePersistEvent1
+ extends RemoteEvent
+{
+
+ @XmlElement(required = true)
+ protected String branchGuid;
+ protected int transactionId;
+ @XmlElement(required = true)
+ protected List<RemoteBasicGuidArtifact1> artifacts;
+ @XmlElement(required = true)
+ protected List<RemoteBasicGuidRelation1> relations;
+ @XmlElement(required = true)
+ protected RemoteNetworkSender1 networkSender;
+
+ /**
+ * Gets the value of the branchGuid property.
+ *
+ * @return
+ * possible object is
+ * {@link String }
+ *
+ */
+ public String getBranchGuid() {
+ return branchGuid;
+ }
+
+ /**
+ * Sets the value of the branchGuid property.
+ *
+ * @param value
+ * allowed object is
+ * {@link String }
+ *
+ */
+ public void setBranchGuid(String value) {
+ this.branchGuid = value;
+ }
+
+ /**
+ * Gets the value of the transactionId property.
+ *
+ */
+ public int getTransactionId() {
+ return transactionId;
+ }
+
+ /**
+ * Sets the value of the transactionId property.
+ *
+ */
+ public void setTransactionId(int value) {
+ this.transactionId = value;
+ }
+
+ /**
+ * Gets the value of the artifacts property.
+ *
+ * <p>
+ * This accessor method returns a reference to the live list,
+ * not a snapshot. Therefore any modification you make to the
+ * returned list will be present inside the JAXB object.
+ * This is why there is not a <CODE>set</CODE> method for the artifacts property.
+ *
+ * <p>
+ * For example, to add a new item, do as follows:
+ * <pre>
+ * getArtifacts().add(newItem);
+ * </pre>
+ *
+ *
+ * <p>
+ * Objects of the following type(s) are allowed in the list
+ * {@link RemoteBasicGuidArtifact1 }
+ *
+ *
+ */
+ public List<RemoteBasicGuidArtifact1> getArtifacts() {
+ if (artifacts == null) {
+ artifacts = new ArrayList<RemoteBasicGuidArtifact1>();
+ }
+ return this.artifacts;
+ }
+
+ /**
+ * Gets the value of the relations property.
+ *
+ * <p>
+ * This accessor method returns a reference to the live list,
+ * not a snapshot. Therefore any modification you make to the
+ * returned list will be present inside the JAXB object.
+ * This is why there is not a <CODE>set</CODE> method for the relations property.
+ *
+ * <p>
+ * For example, to add a new item, do as follows:
+ * <pre>
+ * getRelations().add(newItem);
+ * </pre>
+ *
+ *
+ * <p>
+ * Objects of the following type(s) are allowed in the list
+ * {@link RemoteBasicGuidRelation1 }
+ *
+ *
+ */
+ public List<RemoteBasicGuidRelation1> getRelations() {
+ if (relations == null) {
+ relations = new ArrayList<RemoteBasicGuidRelation1>();
+ }
+ return this.relations;
+ }
+
+ /**
+ * Gets the value of the networkSender property.
+ *
+ * @return
+ * possible object is
+ * {@link RemoteNetworkSender1 }
+ *
+ */
+ public RemoteNetworkSender1 getNetworkSender() {
+ return networkSender;
+ }
+
+ /**
+ * Sets the value of the networkSender property.
+ *
+ * @param value
+ * allowed object is
+ * {@link RemoteNetworkSender1 }
+ *
+ */
+ public void setNetworkSender(RemoteNetworkSender1 value) {
+ this.networkSender = value;
+ }
+
+}
diff --git a/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionDeletedEvent1.java b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionChange1.java
index d50c133361b..e588b85e15b 100644
--- a/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionDeletedEvent1.java
+++ b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionChange1.java
@@ -2,7 +2,7 @@
// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vJAXB 2.1.3 in JDK 1.6
// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2010.05.13 at 02:00:51 PM MST
+// Generated on: 2010.05.28 at 02:08:30 PM MST
//
@@ -18,17 +18,18 @@ import org.eclipse.osee.framework.messaging.event.res.RemoteEvent;
/**
* <p>Java class for RemoteTransactionDeletedEvent1 complex type.
*
* <p>The following schema fragment specifies the expected content contained within this class.
*
* <pre>
- * &lt;complexType name="RemoteTransactionDeletedEvent1">
+ * &lt;complexType name="RemoteTransactionChange1">
* &lt;complexContent>
* &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
* &lt;sequence>
- * &lt;element name="transactionIds" type="{http://www.w3.org/2001/XMLSchema}string" maxOccurs="unbounded"/>
- * &lt;element name="networkSender" type="{}RemoteNetworkSender1"/>
+ * &lt;element name="branchGuid" type="{http://www.w3.org/2001/XMLSchema}string"/>
+ * &lt;element name="transactionId" type="{http://www.w3.org/2001/XMLSchema}int"/>
+ * &lt;element name="artifacts" type="{}RemoteBasicGuidArtifact1" maxOccurs="unbounded"/>
* &lt;/sequence>
* &lt;/restriction>
* &lt;/complexContent>
@@ -38,70 +39,88 @@ import org.eclipse.osee.framework.messaging.event.res.RemoteEvent;
*
*/
@XmlAccessorType(XmlAccessType.FIELD)
-@XmlType(name = "RemoteTransactionDeletedEvent1", propOrder = {
- "transactionIds",
- "networkSender"
+@XmlType(name = "RemoteTransactionChange1", propOrder = {
+ "branchGuid",
+ "transactionId",
+ "artifacts"
})
-public class RemoteTransactionDeletedEvent1
+public class RemoteTransactionChange1
extends RemoteEvent
{
@XmlElement(required = true)
- protected List<String> transactionIds;
+ protected String branchGuid;
+ protected int transactionId;
@XmlElement(required = true)
- protected RemoteNetworkSender1 networkSender;
+ protected List<RemoteBasicGuidArtifact1> artifacts;
/**
- * Gets the value of the transactionIds property.
+ * Gets the value of the branchGuid property.
+ *
+ * @return
+ * possible object is
+ * {@link String }
+ *
+ */
+ public String getBranchGuid() {
+ return branchGuid;
+ }
+
+ /**
+ * Sets the value of the branchGuid property.
+ *
+ * @param value
+ * allowed object is
+ * {@link String }
+ *
+ */
+ public void setBranchGuid(String value) {
+ this.branchGuid = value;
+ }
+
+ /**
+ * Gets the value of the transactionId property.
+ *
+ */
+ public int getTransactionId() {
+ return transactionId;
+ }
+
+ /**
+ * Sets the value of the transactionId property.
+ *
+ */
+ public void setTransactionId(int value) {
+ this.transactionId = value;
+ }
+
+ /**
+ * Gets the value of the artifacts property.
*
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the transactionIds property.
*
* <p>
* For example, to add a new item, do as follows:
* <pre>
- * getTransactionIds().add(newItem);
+ * getArtifacts().add(newItem);
* </pre>
*
*
* <p>
* Objects of the following type(s) are allowed in the list
- * {@link String }
+ * {@link RemoteBasicGuidArtifact1 }
*
*
*/
- public List<String> getTransactionIds() {
- if (transactionIds == null) {
- transactionIds = new ArrayList<String>();
+ public List<RemoteBasicGuidArtifact1> getArtifacts() {
+ if (artifacts == null) {
+ artifacts = new ArrayList<RemoteBasicGuidArtifact1>();
}
- return this.transactionIds;
- }
-
- /**
- * Gets the value of the networkSender property.
- *
- * @return
- * possible object is
- * {@link RemoteNetworkSender1 }
- *
- */
- public RemoteNetworkSender1 getNetworkSender() {
- return networkSender;
- }
-
- /**
- * Sets the value of the networkSender property.
- *
- * @param value
- * allowed object is
- * {@link RemoteNetworkSender1 }
- *
- */
- public void setNetworkSender(RemoteNetworkSender1 value) {
- this.networkSender = value;
+ return this.artifacts;
}
}
@@ -18,17 +18,18 @@ import org.eclipse.osee.framework.messaging.event.res.RemoteEvent;
/**
- * <p>Java class for RemoteTransactionDeletedEvent1 complex type.
+ * <p>Java class for RemoteTransactionChange1 complex type.
*
* <p>The following schema fragment specifies the expected content contained within this class.
@@ -38,70 +39,88 @@ import org.eclipse.osee.framework.messaging.event.res.RemoteEvent;
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
- * This is why there is not a <CODE>set</CODE> method for the transactionIds property.
+ * This is why there is not a <CODE>set</CODE> method for the artifacts property.
*
* <p>
diff --git a/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionEvent1.java b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionEvent1.java
index de1fdcc699d..9f0e969a61c 100644
--- a/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionEvent1.java
+++ b/plugins/org.eclipse.osee.framework.messaging.event.res/src-gen/org/eclipse/osee/framework/messaging/event/res/msgs/RemoteTransactionEvent1.java
@@ -2,7 +2,7 @@
// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, vJAXB 2.1.3 in JDK 1.6
// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2010.05.13 at 02:00:51 PM MST
+// Generated on: 2010.05.28 at 02:08:30 PM MST
//
@@ -27,10 +27,8 @@ import org.eclipse.osee.framework.messaging.event.res.RemoteEvent;
* &lt;complexContent>
* &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
* &lt;sequence>
- * &lt;element name="branchGuid" type="{http://www.w3.org/2001/XMLSchema}string"/>
- * &lt;element name="transactionId" type="{http://www.w3.org/2001/XMLSchema}int"/>
- * &lt;element name="artifacts" type="{}RemoteBasicGuidArtifact1" maxOccurs="unbounded"/>
- * &lt;element name="relations" type="{}RemoteBasicGuidRelation1" maxOccurs="unbounded"/>
+ * &lt;element name="eventTypeGuid" type="{http://www.w3.org/2001/XMLSchema}string"/>
+ * &lt;element name="transactions" type="{}RemoteTransactionChange1" maxOccurs="unbounded"/>
* &lt;element name="networkSender" type="{}RemoteNetworkSender1"/>
* &lt;/sequence>
* &lt;/restriction>
@@ -42,10 +40,8 @@ import org.eclipse.osee.framework.messaging.event.res.RemoteEvent;
*/
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RemoteTransactionEvent1", propOrder = {
- "branchGuid",
- "transactionId",
- "artifacts",
- "relations",
+ "eventTypeGuid",
+ "transactions",
"networkSender"
})
public class RemoteTransactionEvent1
@@ -53,111 +49,63 @@ public class RemoteTransactionEvent1
{
@XmlElement(required = true)
- protected String branchGuid;
- protected int transactionId;
+ protected String eventTypeGuid;
@XmlElement(required = true)
- protected List<RemoteBasicGuidArtifact1> artifacts;
- @XmlElement(required = true)
- protected List<RemoteBasicGuidRelation1> relations;
+ protected List<RemoteTransactionChange1> transactions;
@XmlElement(required = true)
protected RemoteNetworkSender1 networkSender;
/**
* Gets the value of the branchGuid property.
*
* @return
* possible object is
* {@link String }
*
*/
- public String getBranchGuid() {
- return branchGuid;
+ public String getEventTypeGuid() {
+ return eventTypeGuid;
}
/**
* Sets the value of the branchGuid property.
*
* @param value
* allowed object is
* {@link String }
*
*/
- public void setBranchGuid(String value) {
- this.branchGuid = value;
- }
-
- /**
- * Gets the value of the transactionId property.
- *
- */
- public int getTransactionId() {
- return transactionId;
- }
-
- /**
- * Sets the value of the transactionId property.
- *
- */
- public void setTransactionId(int value) {
- this.transactionId = value;
- }
-
- /**
- * Gets the value of the artifacts property.
- *
- * <p>
- * This accessor method returns a reference to the live list,
- * not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
- * This is why there is not a <CODE>set</CODE> method for the artifacts property.
- *
- * <p>
- * For example, to add a new item, do as follows:
- * <pre>
- * getArtifacts().add(newItem);
- * </pre>
- *
- *
- * <p>
- * Objects of the following type(s) are allowed in the list
- * {@link RemoteBasicGuidArtifact1 }
- *
- *
- */
- public List<RemoteBasicGuidArtifact1> getArtifacts() {
- if (artifacts == null) {
- artifacts = new ArrayList<RemoteBasicGuidArtifact1>();
- }
- return this.artifacts;
+ public void setEventTypeGuid(String value) {
+ this.eventTypeGuid = value;
}
/**
* Gets the value of the relations property.
*
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the relations property.
*
* <p>
* For example, to add a new item, do as follows:
* <pre>
- * getRelations().add(newItem);
+ * getTransactions().add(newItem);
* </pre>
*
*
* <p>
* Objects of the following type(s) are allowed in the list
- * {@link RemoteBasicGuidRelation1 }
+ * {@link RemoteTransactionChange1 }
*
*
*/
- public List<RemoteBasicGuidRelation1> getRelations() {
- if (relations == null) {
- relations = new ArrayList<RemoteBasicGuidRelation1>();
+ public List<RemoteTransactionChange1> getTransactions() {
+ if (transactions == null) {
+ transactions = new ArrayList<RemoteTransactionChange1>();
}
- return this.relations;
+ return this.transactions;
}
/**
@@ -53,111 +49,63 @@ public class RemoteTransactionEvent1
protected RemoteNetworkSender1 networkSender;
/**
- * Gets the value of the branchGuid property.
+ * Gets the value of the eventTypeGuid property.
*
* @return
@@ -53,111 +49,63 @@ public class RemoteTransactionEvent1
}
/**
- * Sets the value of the branchGuid property.
+ * Sets the value of the eventTypeGuid property.
*
* @param value
@@ -53,111 +49,63 @@ public class RemoteTransactionEvent1
}
/**
- * Gets the value of the relations property.
+ * Gets the value of the transactions property.
*
* <p>
@@ -53,111 +49,63 @@ public class RemoteTransactionEvent1
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
- * This is why there is not a <CODE>set</CODE> method for the relations property.
+ * This is why there is not a <CODE>set</CODE> method for the transactions property.
*
* <p>

Back to the top